SHIPPING AND SHIPBUILDING IN THE MARITIME PROVINCES IN THE 19TH CENTURY 

Charles Armour and D.A. Muise 

     Maritimers have long held dear their heritage as a sea-going people. Proximity to the ocean and the availability of material resources adaptable to exploitation made the sea-faring life a natural part of their experience. Indeed, many of the original European settlers had been attracted to the area to pursue trades related to the sea, either to fish in the coastal waters or to participate in the harvesting of the vast timber reserves of the region for export to foreign markets. Both activities led inevitably to the development of shipbuilding and shipping, first as adjuncts to those staple industries and later as an industry at least partially capable of sustaining its own growth.

     The world of the 18th and 19th centuries was structured in wood. European immigrants crossed the Atlantic in wooden sailing vessels. For them the sea often represented an ordeal, a barrier to be conquered. Later it would be less a barrier and more a frontier, rich in natural resources and a true vehicle for material advancement. In a world without vessels powered by steam or constructed of steel, the wooden hulled sailing ship was supreme on the oceans of the world.

     In the way that they adapted to the life of the sea, Maritimers exhibited a resourcefulness that made the age of "Wood, Wind and Sail" one of almost epic proportions, studded with tales of great courage and achievement and reflecting a glory that did not survive the modern age.

Why Shipbuilding Became an Industry in the Maritimes 

     The shipping industry of the Maritime provinces owed its birth and maturation to external forces. Although the advantageous geographic position of the Maritimes and a convergence of natural resources were important, external factors such as wars in Europe and America, or artificially supported demands for colonial resources like timber more often spurred development. The periods of rapid expansion of Maritime shipping were prompted and curtailed by these external factors, from the Seven Years War in the mid-18th century to the Crimean War of the 1850's and the American Civil War of the 1860's. Wars set people and goods in motion, allowing an enterprising outsider the leverage necessary to exploit potential. Nothing improved the position of a shipbuilding nation more than somebody else's war; or a large scale movement of people or commodities, like the gold rushes to California and Australia in the 1850's. The initial, pre-1800 phase of shipping development in the Maritimes had little relationship to shipbuilding. The Seven Years War (1754-1760) and the American War of Independence (1774-1783) had brought a commercial class into the area. Members of this community were often agents of larger British concerns or entrepreneurs from the older American colonies to the south. Most began with some involvement in aspects of the provisioning trade for the British troops when Halifax became the centre of British sea power in North America. Almost all the ships active in the province prior to 1780, and they were comparatively few in number, had been built elsewhere. The only exceptions to this were the skiffs or shallops used in the inshore fishery by Acadian fishermen on Cape Breton Island and the small open decked boats used by the earliest settlers. A few schooners, not much bigger than the open decked boats used in the inshore fishery, were employed as coal boats, carrying fuel from the mines in Cape Breton to supply the garrison in Halifax. These vessels did not usually exceed fifty tons capacity. 

     Shipping was intimately linked with commercial development, and commercial activity, to a large extent, was linked with the region's association with the British Empire. The American Revolution, which brought on the collapse of the first British Empire, gave the Maritime area an unprecedented opportunity for growth and development within the protected confines of the new Imperial system. Initially this protection was expressed in laws which excluded United States vessels from participation in the lucrative West Indies Trade. These Navigation Acts gave preference to Imperial shipping and commerce, and Maritime merchants were quick to defend their right to supply the West Indies with staple goods such as fish and barrel staves as well as food-stuffs. This early development led to an accumulation of capital and expertise that would eventually equip the Maritimes for substantial investment in ship construction. The advantages provided by continued membership in the Empire were such that Maritime merchants often found it profitable to become its most exuberant supporters. 

     A related external factor, one of perhaps greater significance, was the shortage of ship and construction timber which developed in Britain at the turn of the century. The Napoleonic Wars led to the closure of Baltic Ports to English timber merchants and North America soon became their chief source of supply. The enormous timber reserves of British North America were subsequently put under the axe for shipment across the Atlantic. More than anything else, this development brought on the expansion of shipbuilding in the Maritimes. It provided a commodity in bulk requiring enormous quantities of shipping tonnage, and, for the first time, focused the attention of British entrepreneurs on the Maritimes as an area of investment potential. 

     A second major resource base in the Maritimes also contributed enormously to the emergence of a shipping industry. The rich off-shore fishery of the Western North Atlantic had been attracting Europeans since the 16th century. The settlers who had come to the many bays and harbours, of Nova Scotia especially, were often experienced in gaining their livelihood from the sea. This was particularly true of the New Englanders who came both before and after the American Revolution. For the pioneer, fish was a relatively easily harvested cash crop. Even the inexperienced, like the German settlers planted at Lunenburg in the 1750's, were soon capable of some involvement in the fishery. There resulted a people who rapidly became adept at the occupations that took them to sea. The sea also provided the easiest access from settlement to settlement. It was only a small step from fisherman to sailor; the sons of many of the first settlers would make the transition easily. 

II  Design, Construction and Investment 

     The first decades of the 19th century witnessed the dramatic accumulation of capital in the Maritimes in connection with shipbuilding and the timber industry. The British merchants who sent their agents to North America were quick to see that all the resources necessary for ship construction were ready at hand and required only the injection of skilled labour and management. Skilled tradesmen were brought directly from Britain to supervise the construction of vessels, though local labour was quickly integrated into the industry. The complexity of ship construction required the co-ordination of many trades - ship carpenters, sailmakers, and a variety of metal workers - and thins could benefit from experienced British overseers. 

     In these early years ship design was relatively primitive and Maritime workmanship often failed to meet European standards. In some cases vessels were little more than oceangoing timber barges which were broken up on arrival in Britain. These ungainly vessels contributed to the low reputation of colonial ships which prevailed during the first third of the century. This was a passing phase, however, and colonial ships were gaining a fully-warranted reputation for excellence by the 1830's and 1840's. That period marked the takeoff in colonial shipbuilding and also featured the emergence of colonial designers of excellence. The internationally famous Donald McKay was a product of this era. His experience reflects the extent to which the industry in the Maritimes was an integral part of the evolving industry along the North Atlantic seaboard. Technological and design innovations were rapid during the middle third of the century and the Maritime builders were as active as their counterparts elsewhere in developing and adapting new and better ways of constructing ocean-going vessels. 

     The 'Golden Age' of construction also marked the apex of the sailing vessel as an instrument of the economy of the Maritimes. It was one thing to apply technical skills to a natural resource in order to produce a marketable commodity. It was quite another to employ the product of those skills in a competitive market. The Maritimers were quick to seize these advantages and turn ship construction into a truly phenomenal pattern of entrepreneurship. Within the space of a generation, the Maritime colonies rose from a relative non-entity in world shipping to a position among the leaders in terms of tonnage owned and operated. By the 1850's the combined operation of the three Maritime colonies was sufficient to rank them fourth behind Great Britain, France and the United States among the sailing nations of the world. 

     This dramatic growth occurred because merchants and investors were prepared to cooperate in the construction, ownership, and operation of shipping. A complex pattern of investment, in which builders and suppliers often held part-interest in a given vessel or group of vessels, made shipping a community-based economy which pervaded almost all aspects of Maritime society. This was possible because there was relatively little necessity for heavy capital expenditures in the development of a shipyard. In fact, the industry was so dispersed that it would be difficult to find a centre of prime importance. Often, the location of a shipyard was dependent on proximity to suitable timber or availability of a suitable labour pool; shipyards often shifted from harbour to harbour. 

     The closest approximation to a centre for the industry was Saint John, N.B., where the vast timber reserves of the Saint John River guaranteed a constant supply of the timber essential for shipbuilding. These ship-yards at Saint John were renowned the world over, and, during the 19th century, produced some of the biggest and most successful square-rigged vessels built anywhere in the world. The Marco Polo (1,625 tons), built in 1851, was perhaps the most famous of these larger vessels but there were many more of equal size and importance. These larger ships, of course, required a greater accumulation of capital and labour than most Maritime ship-yards were capable. The thousands of schooners, barques, and brigantines built all along the coast required enormous skill and enterprise but were usually the product of much smaller operations which subcontracted various aspects of construction. 

     The relationship between ship construction and ship ownership and operation is not as obvious as it might seem at first glance. Often the two were quite distinct. Most ships were probably built on a commission by builders, either for local merchants or on consignment for foreign buyers. Ship ownership, on the other hand, could be as simple as operating a small fishing schooner in the off-shore fishery or as complex as owning a fleet of several vessels employing dozens of mariners and operating on the seven seas. Some vessels were built for almost immediate sale, others were kept in Maritime ownership for years and years and worked for their owners on a continuing basis. This was particularly true of the few decades following 1850 when comparatively free world trade and an upsurge of international cargoes placed efficient shipping at a premium. It was the last great era of the sailing vessel and the Maritimers were probably more proficient at running freights than any sailors in the world. 

III Shipping and Maritime Society 

     The inter-relationship between the people and politics of the Maritimes and sea-going activities during this period was so commonplace it hardly rated commentary from those who participated. The coming and going of dozens of ships which had touched all points of the globe was an almost daily occurrence in smaller ports like Yarmouth and Sydney, not to mention major centres like Halifax and Saint John. It was not uncommon for vessels to be away from their home ports for as much as two or three years. Such voyages might involve dozens of distinct cargoes and voyages and often included several Atlantic crossings as well as activity in the Pacific. Young Maritimers were able to visit the far corners of the earth and often rose quickly to command their own vessels. Many ships' captains were well under thirty years of age while commanding vessels that employed up to twenty mariners. This is a bit less surprising when we remember that cabin-boys and deck hands shipped out as young as ten or twelve years old. Sometimes, the family of the captain or the mate shipped aboard for a voyage; so that boys and girls could experience the life of the sea at very early age. 

     The sailing vessel was, of course, a relatively dangerous mode of transportation. The sea-faring man had only a few instruments to judge position and speed and few safety devices. At sea, the vessel was an autocracy. The lives of an entire crew relied on captain's judgment about taking sail or changing course in heavy weather. Most vessels were relatively small compared to modern giants and were subject to the vagaries of wind and weather. No matter how capable the seafarers, the loss of vessels and lives was a regular feature of the Maritime life. Ferocious storms could wipe out dozens of ships and hundreds of men in a single stroke. In some parts of the Maritimes, where shipping was most extensive, hardly a family was untouched by the ravages of the sea. 

     The useful life of a wooden sailing vessel was not unlimited. Vessels were categorized for insurance purposes by a complicated system of measures reflecting the nature of materials, the reputation of her builders, and a host of related items. Most important, insurance ratings were affected by age. After five or ten years at sea, it became more difficult for vessels to get top insurance for freights. The result was that ships often spent their early years of peak capacity working almost to the breaking point to maximize profits for the builder and owner. These vessels often went to a rather ignoble end as coal boats or coasters, carrying bulky and low-value cargoes for lower insurance. It was usually only a matter of time before a vessel treated in this way was claimed by the sea. The life expectancy of a well-constructed vessel could be as much as twenty years, but that was the exception rather than the rule.

     Respectable fortunes were made by a small group of Maritime entrepreneurs who exploited international circumstances to employ the geographical advantage and human resources of the area. These phenomena did not, however, provide a firm base for continued economic development. The earnings of the shipping industry were based on the provision of services on the international market. As long as the Maritimers were competitive, the earnings were consistent, but they seldom resulted in the development of any capital intensive industrial capacity in the area, save for one or two towns like St. John and Yarmouth. The investment in shipping was, in fact, relatively fluid; i.e. capable of being withdrawn from the industry and re-invested in more remunerative areas of the economy. With the collapse of the wooden-hulled sailing vessel and its replacement by steel-hulled, steam-powered, ocean-going vessels, the Maritime economy suffered a severe shock. The lack of a diversified base made the area particularly vulnerable to changes in the international economy. When this weakness combined with Confederation and the resulting re-orientation of Canada's trade patterns, the traditional economy faced disaster. Fortunately, the emergence of the coal-mining industry and some industrial development in Nova Scotia and the development of pulp and paper in New Brunswick eased the shock.    From this involvement with the sea emerged the rich heritage which colours the fabric of the Maritimes. The age of "Wooden Ships and Iron Men" abounds with tales of individual heroism against the terrible adversity of the sea. Embellished by generations of retelling, these romantic tales continue to excite the imagination of poet and story-teller. The decline of the shipping industry during the final third of the century and the subsequent demise of the dozens of tiny ports that had served the industry so well has created among Maritimers an understandable nostalgia for the `Golden Age' of the pre-Confederation era.  

